@@ -9,6 +9,7 @@
 
 #include <QCommandLineParser>
 #include <QDir>
+#include <QIcon>
 
 #include <KAboutData>
 #include <KCrash>
@@ -41,6 +42,8 @@ int main(int argc, char *argv[])
 
     KAboutData::setApplicationData(about);
 
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kgpg")));
+
     QCommandLineParser parser;
     parser.setApplicationDescription(about.shortDescription());
     about.setupCommandLine(&parser);
